Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2160)

Unified Diff: content/renderer/shared_worker/embedded_shared_worker_stub.cc

Issue 2714423002: Rename SkipServiceWorker to ServiceWorkerMode (Closed)
Patch Set: typos-- Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/shared_worker/embedded_shared_worker_stub.cc
diff --git a/content/renderer/shared_worker/embedded_shared_worker_stub.cc b/content/renderer/shared_worker/embedded_shared_worker_stub.cc
index b0ac6424920b16c963ed56cec421af72f3e9439c..eb8d6e33d68a6a42660212760d8fac5ab568c68d 100644
--- a/content/renderer/shared_worker/embedded_shared_worker_stub.cc
+++ b/content/renderer/shared_worker/embedded_shared_worker_stub.cc
@@ -96,17 +96,17 @@ class WebServiceWorkerNetworkProviderImpl
request.setExtraData(extra_data.release());
// If the provider does not have a controller at this point, the renderer
// expects subresource requests to never be handled by a controlling service
// worker, so set the SkipServiceWorker flag here. Otherwise, a service
// worker that is in the process of becoming the controller (i.e., via
// claim()) on the browser-side could handle the request and break the
// assumptions of the renderer.
if (request.getRequestContext() !=
blink::WebURLRequest::RequestContextSharedWorker &&
!provider->IsControlledByServiceWorker() &&
- request.skipServiceWorker() !=
- blink::WebURLRequest::SkipServiceWorker::All) {
- request.setSkipServiceWorker(
- blink::WebURLRequest::SkipServiceWorker::Controlling);
+ request.getServiceWorkerMode() !=
+ blink::WebURLRequest::ServiceWorkerMode::None) {
+ request.setServiceWorkerMode(
+ blink::WebURLRequest::ServiceWorkerMode::Foreign);
}
}
« no previous file with comments | « content/renderer/render_frame_impl.cc ('k') | third_party/WebKit/Source/core/inspector/InspectorNetworkAgent.cpp » ('j') | no next file with comments »
@@ -96,17 +96,17 @@ class WebServiceWorkerNetworkProviderImpl
// If the provider does not have a controller at this point, the renderer
// expects subresource requests to never be handled by a controlling service
- // worker, so set the SkipServiceWorker flag here. Otherwise, a service
- // worker that is in the process of becoming the controller (i.e., via
- // claim()) on the browser-side could handle the request and break the
- // assumptions of the renderer.
+ // worker, so set the ServiceWorkerMode to skip local workers here.
+ // Otherwise, a service worker that is in the process of becoming the
+ // controller (i.e., via claim()) on the browser-side could handle the
+ // request and break the assumptions of the renderer.
if (request.getRequestContext() !=
blink::WebURLRequest::RequestContextSharedWorker &&

Powered by Google App Engine
This is Rietveld 408576698